@@ -11,7 +11,7 @@
 #include "config-musicbrainz.h"
 #include <QTest>
 
-static void setEnvironment()
+void MusicBrainzTestSeveralDiscs::initMain()
 {
     qputenv("LANG", "C.UTF-8");
     qputenv("LANGUAGE", "C.UTF-8");
@@ -127,6 +127,4 @@ void MusicBrainzTestSeveralDiscs::testLookup()
   }
 }
 
-Q_COREAPP_STARTUP_FUNCTION(setEnvironment)
-
 QTEST_GUILESS_MAIN(MusicBrainzTestSeveralDiscs)
